import 'package:flutter/material.dart';

import 'package:spartathlon_app/providers/LicenseData.dart';
import 'package:spartathlon_app/util/Utils.dart';

/// About View
///
/// This view displays info about the race itself, the app and credits

String versionName = '0.3.0';

class AboutView extends StatefulWidget {
  AboutView({Key key}) : super(key: key);

  @override
  _AboutViewState createState() => _AboutViewState();
}

class _AboutViewState extends State<AboutView> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('About'),
      ),
      backgroundColor: Theme.of(context).scaffoldBackgroundColor,
      body: _getBody(),
    );
  }

  Widget _getBody() {
    double elevation = 2.0;
    List<ListTile> licenseTiles = licenses
        .map((Map<String, Object> e) => ListTile(
              title:
                  Text(e['name'].toString() + ' by ' + e['author'].toString()),
              subtitle: Text(e['license'].toString()),
              onTap: () {
                Utils.launchUrl(e['url'].toString());
              },
            ))
        .toList();

    return ListView(
      children: [
        Padding(
          padding: EdgeInsets.all(12.0),
          child: Card(
            elevation: elevation,
            child: Column(
              children: [
                ListTile(
                  title: Text(
                    'About the race',
                    style: TextStyle(
                        color: Theme.of(context).primaryColor,
                        fontSize: 18.0,
                        fontWeight: FontWeight.w500),
                  ),
                ),
                Divider(height: 0.0),
                Divider(height: 0.0),
                Padding(
                  padding: EdgeInsets.all(12.0),
                  child: Text(raceDescription),
                ),
                Divider(height: 0.0),
                Divider(height: 0.0),
                ListTile(
                  leading: Icon(Icons.language,
                      color: Theme.of(context).iconTheme.color),
                  trailing: Icon(Icons.open_in_new,
                      color: Theme.of(context).iconTheme.color),
                  title: Text('Website'),
                  onTap: () {
                    Utils.launchUrl('https://spartathlon.gr/en');
                  },
                )
              ],
            ),
          ),
        ),
        Padding(
          padding: EdgeInsets.only(bottom: 12.0, left: 12.0, right: 12.0),
          child: Card(
            elevation: elevation,
            child: Column(
              children: [
                ListTile(
                  title: Text(
                    'About this app',
                    style: TextStyle(
                        color: Theme.of(context).primaryColor,
                        fontSize: 18.0,
                        fontWeight: FontWeight.w500),
                  ),
                ),
                Divider(height: 0.0),
                Divider(height: 0.0),
                ListTile(
                  leading: Icon(Icons.info_outline,
                      color: Theme.of(context).iconTheme.color),
                  title: Text('Version'),
                  trailing: Text(versionName),
                ),
                Divider(height: 0.0),
                Divider(height: 0.0),
                ListTile(
                  leading: Icon(Icons.person_outline,
                      color: Theme.of(context).iconTheme.color),
                  title: Text('Author'),
                  trailing: Text('Thore Goebel'),
                ),
                Divider(height: 0.0),
                Divider(height: 0.0),
                ListTile(
                  leading: Icon(Icons.copyright,
                      color: Theme.of(context).iconTheme.color),
                  trailing: Icon(Icons.open_in_new,
                      color: Theme.of(context).iconTheme.color),
                  title: Text('Licenses'),
                  onTap: () {
                    showDialog(
                      context: context,
                      builder: (context) {
                        return SimpleDialog(
                          title: Text('Licenses'),
                          contentPadding: EdgeInsets.all(6.0),
                          children: [
                            Container(
                              color: Theme.of(context).dialogBackgroundColor,
                              constraints: BoxConstraints.tightFor(
                                width: MediaQuery.of(context).size.width,
                                height:
                                    MediaQuery.of(context).size.height - 300,
                              ),
                              child: ListView(children: licenseTiles),
                            ),
                          ],
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(8.0)),
                        );
                      },
                    );
                  },
                ),
                Divider(height: 0.0),
                Divider(height: 0.0),
                ListTile(
                  leading: Icon(Icons.code,
                      color: Theme.of(context).iconTheme.color),
                  trailing: Icon(Icons.open_in_new,
                      color: Theme.of(context).iconTheme.color),
                  title: Text('Source code'),
                  onTap: () {
                    Utils.launchUrl('https://gitlab.com/thgoebel/spartathlon');
                  },
                ),
                Divider(height: 0.0),
                Divider(height: 0.0),
                ListTile(
                  leading: Icon(Icons.restore,
                      color: Theme.of(context).iconTheme.color),
                  trailing: Icon(Icons.open_in_new,
                      color: Theme.of(context).iconTheme.color),
                  title: Text('Changelog'),
                  onTap: () {
                    Utils.launchUrl(
                        'https://gitlab.com/thgoebel/spartathlon/blob/master/CHANGELOG.md');
                  },
                ),
              ],
            ),
          ),
        ),
      ],
    );
  }

  final String raceDescription =
      'Described as the world\'s most grueling race, the Spartathlon runs over rough tracks and muddy paths (often it rains during the race), crosses vineyards and olive groves, climbs steep hillsides and, most challenging of all, takes the runners on the 1,200 meter ascent and descent of Mount Parthenio in the dead of night. This is the mountain, covered with rocks and bushes, on which it is said Pheidippides met the god Pan.\n'
      'Spartathlon is the event that brings this deed to attention today by drawing a legend out of the depths of history. The idea for its creation is belongs to John Foden, a British RAF Wing Commander. As a lover of Greece and student of ancient Greek history, Foden stopped his reading of Herodotus\' narration regarding Pheidippides, puzzled and wondering if a modern man could cover the distance from Athens to Sparta, i.e. 250 kms, within 36 hours.';
}
