import 'package:flutter/material.dart';

import 'package:flutter_html_view/flutter_html_view.dart';
import 'package:cached_network_image/cached_network_image.dart';

import 'package:spartathlon_app/models/BlogEntry.dart';
import 'package:spartathlon_app/util/Utils.dart';

/// Blog Details View
///
/// Displays a blog entry (race report) with the header image at the top, followed by the report itself.

class BlogFullView extends StatefulWidget {
  BlogFullView({Key key, this.item}) : super(key: key);
  final BlogEntry item;

  @override
  _BlogFullViewState createState() => _BlogFullViewState();
}

class _BlogFullViewState extends State<BlogFullView> {
  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;

    return CustomScrollView(
      slivers: [
        SliverAppBar(
          backgroundColor: Theme.of(context).primaryColor,
          expandedHeight: width,
          floating: false,
          pinned: true,
          actions: [
            PopupMenuButton(
              itemBuilder: (BuildContext context) {
                return [
                  PopupMenuItem(
                    child:
                        Container(width: 120.0, child: Text('Open in browser')),
                    value: widget.item.url,
                  )
                ];
              },
              onSelected: (String url) {
                Utils.launchUrl(url);
              },
            )
          ],
          flexibleSpace: FlexibleSpaceBar(
              // TODO align title text to the far left
              // tracked in https://github.com/flutter/flutter/issues/11951
              title: ConstrainedBox(
                constraints:
                    BoxConstraints(maxWidth: width - 190, maxHeight: 36.0),
                child: Text(widget.item.headline),
              ),
              background: Stack(
                fit: StackFit.expand,
                children: [
                  CachedNetworkImage(
                    imageUrl: widget.item.imageUrl,
                    fit: BoxFit.cover,
                    alignment: Alignment(0, 0.5),
                  ),
                ],
              )),
        ),
        SliverList(
          delegate: SliverChildListDelegate(
            [
              Material(
                child: Container(
                  padding: EdgeInsets.only(
                      left: 8.0, right: 6.0, top: 12.0, bottom: 4.0),
                  child: HtmlView(data: widget.item.fullText),
                ),
              ),
            ],
          ),
        ),
      ],
    );
  }
}
